@@ -10,6 +10,6 @@ class free_school_meals(Variable):
     documentation = "Value of free school meals"
 
     def formula(spm_unit, period, parameters):
-        tier = spm_unit("school_meal_tier", period).decode_to_str()
-        is_free = tier == "FREE"
+        tier = spm_unit("school_meal_tier", period)
+        is_free = tier == tier.possible_values.FREE
         return is_free * spm_unit("school_meal_net_subsidy", period)
